@@ -4,7 +4,7 @@
 
 int main(int argc, const char *argv[])
 {     /* stand-alone LP/MIP solver */
-      return lpx_main(argc, argv);
+      return glp_main(argc, argv);
 }
 
 /* eof */
