@@ -6,9 +6,9 @@
 *  Author: Heinrich Schuchardt <xypron.glpk@gmx.de>.
 *
 *  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-*  2009, 2010 Andrew Makhorin, Department for Applied Informatics,
-*  Moscow Aviation Institute, Moscow, Russia. All rights reserved.
-*  E-mail: <mao@gnu.org>.
+*  2009, 2010, 2011, 2013 Andrew Makhorin, Department for Applied
+*  Informatics, Moscow Aviation Institute, Moscow, Russia. All rights
+*  reserved. E-mail: <mao@gnu.org>.
 *
 *  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
@@ -24,20 +24,23 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#define _GLPSTD_STDIO
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "glpmpl.h"
 #include "glpsql.h"
 
 #ifdef ODBC_DLNAME
 #define HAVE_ODBC
 #define libodbc ODBC_DLNAME
-#define h_odbc (lib_link_env()->h_odbc)
+#define h_odbc (get_env_ptr()->h_odbc)
 #endif
 
 #ifdef MYSQL_DLNAME
 #define HAVE_MYSQL
 #define libmysql MYSQL_DLNAME
-#define h_mysql (lib_link_env()->h_mysql)
+#define h_mysql (get_env_ptr()->h_mysql)
 #endif
 
 static void *db_iodbc_open_int(TABDCA *dca, int mode, const char
@@ -113,10 +116,14 @@ static char **args_concat(TABDCA *dca)
    {
       arg = mpl_tab_get_arg(dca, j);
       len = strlen(arg);
+      /* add length of part */
       lentot += len;
+      /* add length of space separating parts or 0x00 at end of SQL
+         statement */
+      lentot++;
       if (arg[len-1] == ';' || j == narg)
       {  /* Join arguments for a single SQL statement */
-         sqllines[i] = xmalloc(lentot+1);
+         sqllines[i] = xmalloc(lentot);
          sqllines[i+1] = NULL;
          sqllines[i][0] = 0x00;
          for (j1 = j0; j1 <= j; j1++)
@@ -837,8 +844,13 @@ static void *db_iodbc_open_int(TABDCA *dca, int mode, const char
             &nullable);
          sql->isnumeric[i] = is_numeric(sql->coltype[i]);
          /* bind columns to program vars, converting all types to CHAR*/
-         dl_SQLBindCol(sql->hstmt, i, SQL_CHAR, sql->data[i],
-            SQL_FDLEN_MAX, &(sql->outlen[i]));
+         if (sql->isnumeric[i])
+         {  dl_SQLBindCol(sql->hstmt, i, SQL_DOUBLE, sql->data[i],
+               SQL_FDLEN_MAX, &(sql->outlen[i]));
+         } else
+         {  dl_SQLBindCol(sql->hstmt, i, SQL_CHAR, sql->data[i],
+               SQL_FDLEN_MAX, &(sql->outlen[i]));
+         }
          for (j = sql->nf; j >= 1; j--)
          {  if (strcmp(mpl_tab_get_name(dca, j), sql->colname[i]) == 0)
             break;
@@ -888,21 +900,21 @@ int db_iodbc_read(TABDCA *dca, void *link)
       if (sql->ref[i] > 0)
       {
          len = sql->outlen[i];
-         if (len > SQL_FDLEN_MAX)
-            len = SQL_FDLEN_MAX;
-         else if (len < 0)
-            len = 0;
-         strncpy(buf, (const char *) sql->data[i], len);
-         buf[len] = 0x00;
-         if (0 != (sql->isnumeric[i]))
+         if (len != SQL_NULL_DATA)
          {
-            strspx(buf); /* remove spaces*/
-            xassert(str2num(buf, &num) == 0);
-            mpl_tab_set_num(dca, sql->ref[i], num);
-         }
-         else
-         {
-            mpl_tab_set_str(dca, sql->ref[i], strtrim(buf));
+            if (sql->isnumeric[i])
+            {  mpl_tab_set_num(dca, sql->ref[i],
+                               *((const double *) sql->data[i]));
+            }
+            else
+            {  if (len > SQL_FDLEN_MAX)
+                  len = SQL_FDLEN_MAX;
+               else if (len < 0)
+                  len = 0;
+               strncpy(buf, (const char *) sql->data[i], len);
+               buf[len] = 0x00;
+               mpl_tab_set_str(dca, sql->ref[i], strtrim(buf));
+            }
          }
       }
    }
@@ -951,7 +963,11 @@ int db_iodbc_write(TABDCA *dca, void *link)
       strcat( query, part );
       switch (mpl_tab_get_type(dca, k))
       {  case 'N':
+#if 0 /* 02/XI-2010 by xypron */
             sprintf(num, "%-18g",mpl_tab_get_num(dca, k));
+#else
+            sprintf(num, "%.*g", DBL_DIG, mpl_tab_get_num(dca, k));
+#endif
             strcat( query, num );
             break;
          case 'S':
@@ -1497,26 +1513,29 @@ int db_mysql_read(TABDCA *dca, void *link)
    num_fields = dl_mysql_num_fields(sql->res);
    for (i=1; i <= num_fields; i++)
    {
-      len = (size_t) lengths[i-1];
-      if (len > 255)
-         len = 255;
-      strncpy(buf, (const char *) row[i-1], len);
-      buf[len] = 0x00;
-      if (0 != (fields[i-1].flags & NUM_FLAG))
-      {
-         strspx(buf); /* remove spaces*/
-         xassert(str2num(buf, &num) == 0);
-         if (sql->ref[i] > 0)
-            mpl_tab_set_num(dca, sql->ref[i], num);
+      if (row[i-1] != NULL)
+      {  len = (size_t) lengths[i-1];
+         if (len > 255)
+            len = 255;
+         strncpy(buf, (const char *) row[i-1], len);
+         buf[len] = 0x00;
+         if (0 != (fields[i-1].flags & NUM_FLAG))
+         {  strspx(buf); /* remove spaces*/
+            if (str2num(buf, &num) != 0)
+            {  xprintf("'%s' cannot be converted to a number.\n", buf);
+               return 1;
+            }
+            if (sql->ref[i] > 0)
+               mpl_tab_set_num(dca, sql->ref[i], num);
          }
-           else
-         {
-         if (sql->ref[i] > 0)
-            mpl_tab_set_str(dca, sql->ref[i], strtrim(buf));
+         else
+         {  if (sql->ref[i] > 0)
+               mpl_tab_set_str(dca, sql->ref[i], strtrim(buf));
          }
-         }
-   return 0;
+      }
    }
+   return 0;
+}
 
 int db_mysql_write(TABDCA *dca, void *link)
 {
@@ -1560,7 +1579,11 @@ int db_mysql_write(TABDCA *dca, void *link)
       strcat( query, part );
       switch (mpl_tab_get_type(dca, k))
       {  case 'N':
+#if 0 /* 02/XI-2010 by xypron */
             sprintf(num, "%-18g",mpl_tab_get_num(dca, k));
+#else
+            sprintf(num, "%.*g", DBL_DIG, mpl_tab_get_num(dca, k));
+#endif
             strcat( query, num );
             break;
          case 'S':
